@@ -10,6 +10,7 @@ The :py:class:`~uravu.distribution.Distribution` class oversees these operations
 import numpy as np
 from scipy.stats import normaltest, gaussian_kde
 from scipy.optimize import minimize
+from uncertainties import ufloat
 
 
 class Distribution:
@@ -104,22 +105,21 @@ class Distribution:
         Return:
             :py:attr:`float`: Negative probability.
         """
-        return -self.kde.pdf(x) 
-        
+        return -self.kde.pdf(x)
+
     @property
     def dist_max(self):
         """
-        Get the value that maximises the distribution. If no :py:attr:`kde` has been created (for example if the distribution has fewer than 8 values) the median is returned. 
-        
+        Get the value that maximises the distribution. If no :py:attr:`kde` has been created (for example if the distribution has fewer than 8 values) the median is returned.
+
         Returns
             :py:attr:`float`: Most likely value.
         """
-        try: 
-            return minimize(self.negative_pdf, x0=[self.n]).x
+        try:
+            return minimize(self.negative_pdf, x0=[self.n]).x[0]
         except AttributeError:
             return self.n
 
-
     @property
     def min(self):
         """
@@ -195,3 +195,34 @@ class Distribution:
         if self.size > 8:
             self.check_normality()
             self.kde = gaussian_kde(self.samples)
+
+    def __repr__(self, precision=3):
+        """
+        Representation.
+
+        Args:
+            precision (:py:attr:`int`): Precision of output
+
+        Returns:
+            :py:attr:`str`: Representation.
+        """
+        try:
+            exponent = int(np.floor(np.log10(np.abs(self.n))))
+        except OverflowError:
+            exponent = 0
+        if self.normal:
+            return f'({self.n / np.power(10., exponent):.{precision}f}+/-{(self.con_int[1]-self.n) / np.power(10., exponent):.{precision}f})e{exponent}'
+        else:
+            return f'({self.n / np.power(10., exponent):.{precision}f}(+{(self.con_int[1]-self.n) / np.power(10., exponent):.{precision}f}/-{(self.n-self.con_int[0]) / np.power(10., exponent):.{precision}f}))e{exponent}'
+
+    def __str__(self, precision=3):
+        """
+        String representation.
+
+        Args:
+            precision (:py:attr:`int`): Precision of output
+
+        Returns:
+            :py:attr:`str`: String representation.
+        """
+        return self.__repr__(precision)
