@@ -16,7 +16,7 @@ try:
     from uravu import _fig_params
     colors = _fig_params.colors
 except ModuleNotFoundError:
-    print("The matplotlib, corner and seaborn packages are necessary for the use of the plotting module, please install these.")
+    raise ModuleNotFoundError("The matplotlib, corner and seaborn packages are necessary for the use of the plotting module, please install these.")
 
 
 def plot_relationship(relationship, axes=None, figsize=(10, 6)):  # pragma: no cover
